@@ -176,17 +176,11 @@ namespace SourceGit.Models
             set;
         } = false;
 
-        public bool KeepIndexWhenStash
+        public int ChangesAfterStashing
         {
             get;
             set;
-        } = false;
-
-        public bool AutoRestoreAfterStash
-        {
-            get;
-            set;
-        } = false;
+        } = 0;
 
         public string PreferredOpenAIService
         {
@@ -287,9 +281,8 @@ namespace SourceGit.Models
                 return false;
             }
 
-            for (int i = 0; i < HistoriesFilters.Count; i++)
+            foreach (var filter in HistoriesFilters)
             {
-                var filter = HistoriesFilters[i];
                 if (filter.Type != type)
                     continue;
 
