@@ -44,9 +44,15 @@ namespace SourceGit.ViewModels
             var updateSubmodules = IsRecurseSubmoduleVisible && RecurseSubmodules;
             return Task.Run(() =>
             {
-                var succ = false;
+                bool succ;
                 var needPop = false;
 
+                if (!_repo.ConfirmCheckoutBranch())
+                {
+                    CallUIThread(() => _repo.SetWatcherEnabled(true));
+                    return true;
+                }
+
                 if (DiscardLocalChanges)
                 {
                     succ = new Commands.Checkout(_repo.FullPath).Use(log).Commit(Commit.SHA, true);
