@@ -21,6 +21,12 @@ namespace SourceGit.ViewModels
             set;
         }
 
+        public bool Edit
+        {
+            get;
+            set;
+        } = false;
+
         public Merge(Repository repo, Models.Branch source, string into, bool forceFastForward)
         {
             _repo = repo;
@@ -54,6 +60,7 @@ namespace SourceGit.ViewModels
         public override Task<bool> Sure()
         {
             _repo.SetWatcherEnabled(false);
+            _repo.ClearCommitMessage();
             ProgressDescription = $"Merging '{_sourceName}' into '{Into}' ...";
 
             var log = _repo.CreateLog($"Merging '{_sourceName}' into '{Into}'");
@@ -61,13 +68,13 @@ namespace SourceGit.ViewModels
 
             return Task.Run(() =>
             {
-                new Commands.Merge(_repo.FullPath, _sourceName, Mode.Arg).Use(log).Exec();
+                new Commands.Merge(_repo.FullPath, _sourceName, Mode.Arg, Edit).Use(log).Exec();
                 log.Complete();
 
                 var head = new Commands.QueryRevisionByRefName(_repo.FullPath, "HEAD").Result();
                 CallUIThread(() =>
                 {
-                    _repo.NavigateToCommitDelayed(head);
+                    _repo.NavigateToCommit(head, true);
                     _repo.SetWatcherEnabled(true);
                 });
                 return true;
