@@ -32,7 +32,9 @@ namespace SourceGit.Views
                 var selected = await StorageProvider.OpenFolderPickerAsync(options);
                 if (selected.Count == 1)
                 {
-                    workspace.Selected.DefaultCloneDir = selected[0].Path.LocalPath;
+                    var folder = selected[0];
+                    var folderPath = folder is { Path: { IsAbsoluteUri: true } path } ? path.LocalPath : folder?.Path.ToString();
+                    workspace.Selected.DefaultCloneDir = folderPath;
                 }
             }
             catch (Exception ex)
