@@ -157,6 +157,9 @@ namespace SourceGit.Views
         {
             if (DataContext is ViewModels.Repository { CurrentBranch: not null } repo)
             {
+                var repoView = TopLevel.GetTopLevel(this)?.FindDescendantOfType<Repository>();
+                repoView?.LocalBranchTree?.Select(repo.CurrentBranch);
+
                 repo.NavigateToCommit(repo.CurrentBranch.Head);
                 e.Handled = true;
             }
